# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0020_old_tree_cleanup'),
        ('comment', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='RecentResponsePlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='comment_recentresponseplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('limit', models.PositiveIntegerField(default=6)),
                ('renderTemplate', models.CharField(default=b'comment/RecentResponse.html', max_length=150, verbose_name='Comment Template', blank=True, choices=[(b'comment/RecentResponse.html', 'Default')])),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
